/* ========================================
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 * ========================================
*/
/*******************************************************************************
* File Name: main.c
* 
* Description: This program takes analog input (0,0v to 3,3v) from pin P0.7 
*              and display converted result on LCD 
*
* ADC Configuration:
*             16-Bit ADC mit Del_Sig
*             conversion Mode: Single Sample
*             Input Range:     Vssa to Vdda (0,0v to 3,3v)
*             Input Mode:      Single Ended
* 
* Hardware Connections:
*    Connect analog input to port P0[7] of DVK1 board.
*
* PWM Configuration:
*             16-Bit UDB PWM
*             Period: 65535 changed to 60000 for a round 5ms
*             Interrupt: None
*             Output Pin: P0.0 (PWM 2)
                          P0.1 (PWM 1)
* Clock Frequency 12 MHz
*
*

*/

#include <project.h>
#define	PWM_PERIOD		60000u		//	leads to a frequency of 200 Hz
#define	Forever			1			//	I like that!

/*******************************************************************************
* Function Name: Sys_Init
********************************************************************************
* Summary:
*  Sys_Init() performs following functions:
*  1: Initializes the LCD
*  2: Initialize all other components
* Parameters: None.
* Return: None.
*******************************************************************************/
void Sys_Init(void)
{
	LCD_Start();
	LCD_Position(0u,0u);
	LCD_PrintString("Initializing..");			
    ADC_DelSig_Start();			  	
	// Start Clock & PWM
//	Clock_Start();					//	Clock is defined as start at reset, no need to start again
	PWM_Start();						
	PWM_WritePeriod(PWM_PERIOD);	//	Overwrite PWM's property
		 
	CyGlobalIntEnable;  			// Comment this line to disable global interrupts.
	CyDelay(1500); 	
	LCD_ClearDisplay(); 	
}
/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  main() performs following functions:
*  1: Starts ADC
*  2: Starts ADC converstion.
*  3: Gets the converted result and displays it in LCD.
*
* Parameters: None.
* Return: None.
*
*******************************************************************************/
uint16 ADC_Max=65535;
uint16 ADC_Min=0;

uint16 i=0;
float Comp_Val;

int main()
{       
int32 ADC_Result;
float Temp;
    // Start the components 
	Sys_Init(); 

    LCD_Position(0u, 0u);
    LCD_PrintString("ADC_Output");
	
	ADC_DelSig_StartConvert();  // Start the ADC conversion *** Changed the mode to Continuos
    while(Forever)
    {
		
        if(ADC_DelSig_IsEndConversion(ADC_DelSig_RETURN_STATUS)) // Check ADC EOC flag
        {
            ADC_Result = ADC_DelSig_GetResult32(); // Get Result
			
			if(ADC_Result < 0)		ADC_Result = 0;	// Limit the result to 0..65535
			if(ADC_Result > 65535)	ADC_Result = 65535;
            LCD_Position(1u, 0u);				
			LCD_PrintDecUint16(ADC_DelSig_CountsTo_mVolts((uint16)ADC_Result)); // Display ADC result in mVolts on LCD
			CyDelay(1000);	
									
			//Comp_Val = (float)(PWM_ReadPeriod() / (ADC_Max * ADC_Result));						 
			//PWM_WritePeriod(PWM_ReadPeriod() );
			//PWM_WriteCompare(Comp_Val); 									
			Temp = (PWM_PERIOD / 65535.0) * ADC_Result; 
			/* i want to do this as per my ADC Result */
//			PWM_WritePeriod(65535);	*** Do not touch the period value, keep that constant
			PWM_WriteCompare1((uint16)Temp); 			
			
        }
    }
}

/* [] END OF FILE */
